Module address

Module address 

Address type detection and validation for IPv4, IPv6, and hostnames

Enums

AddressType
Type of address

Functions

parse_address_type
Parse and determine the type of an address (IPv4, IPv6, or hostname)
validate_address_type_consistency
Validate that all addresses are the same type Returns the common type if all match, or an error if they’re mixed