Module auth_adapter

Module auth_adapter 

Adapter that manages and stores authentication, authorization and other sensitive data.

Structs

AccessToken
Access tokens are used to authenticate users
ActionToken
Action tokens represent federated user actions as signed JWTs (ES384/P-384).
ApiKeyInfo
API key information (without the secret key)
ApiKeyValidation
Result of validating an API key
AuthCtx
Context struct for an authenticated user
AuthKey
Represents a profile key
AuthLogin
AuthProfile
Represents an auth profile
CertData
Certificate associated with a tenant
CreateApiKeyOptions
Options for creating an API key
CreateProxySiteData
Data needed to create a new proxy site
CreateTenantData
Data needed to create a new tenant
CreatedApiKey
Result of creating an API key (includes plaintext key shown only once)
KeyPair
A private/public key pair
ListTenantsOptions
Options for listing tenants
ProxySiteConfig
Configuration for a proxy site (stored as JSON in the config column)
ProxySiteData
Proxy site data from the database
TenantListItem
Tenant list item from auth adapter
UpdateProxySiteData
Data to update an existing proxy site
Webauthn

Constants

ACCESS_TOKEN_EXPIRY

Traits

AuthAdapter
A Cloudillo auth adapter