pub struct CrdtUpdate {
pub data: Vec<u8>,
pub client_id: Option<Box<str>>,
}Expand description
A binary CRDT update (serialized Yjs sync protocol message).
These updates are the fundamental unit of change in CRDT systems. They can be applied in any order and are commutative.
Fields
data: Vec<u8>Raw bytes of the update in Yjs sync protocol format
client_id: Option<Box<str>>Optional user/client ID that created this update
Implementations