CreateIdentityOptions

Struct CreateIdentityOptions 

pub struct CreateIdentityOptions<'a> {
    pub id_tag_prefix: &'a str,
    pub id_tag_domain: &'a str,
    pub email: Option<&'a str>,
    pub registrar_id_tag: &'a str,
    pub owner_id_tag: Option<&'a str>,
    pub status: IdentityStatus,
    pub address: Option<&'a str>,
    pub address_type: Option<AddressType>,
    pub dyndns: bool,
    pub lang: Option<&'a str>,
    pub expires_at: Option<Timestamp>,
}
Options for creating a new identity

Fields

id_tag_prefix: &'a str

The unique identifier prefix (local part) for this identity

id_tag_domain: &'a str

The domain part of the identity identifier

email: Option<&'a str>

Email address to associate with this identity (optional for community-owned identities)

registrar_id_tag: &'a str

The id_tag of the registrar creating this identity

owner_id_tag: Option<&'a str>

The id_tag of the owner who will control this identity (optional) When issuer=“owner” in the registration token, this is set from the token issuer

status: IdentityStatus

Initial status of the identity (default: Pending)

address: Option<&'a str>

Initial address for this identity (optional)

address_type: Option<AddressType>

Type of the address being set (if address is provided)

dyndns: bool

Whether this identity uses dynamic DNS (60s TTL instead of 3600s)

lang: Option<&'a str>

Preferred language for emails and notifications (e.g., “hu”, “de”)

expires_at: Option<Timestamp>

When the identity should expire (optional, can have default)