Address type detection and validation for IPv4, IPv6, and hostnames
Enums
- Address
Type - Type of address
Functions
- parse_
address_ type - Parse and determine the type of an address (IPv4, IPv6, or hostname)
- validate_
address_ type_ consistency - Validate that all addresses are the same type Returns the common type if all match, or an error if they’re mixed