pub fn parse_address_type(address: &str) -> ClResult<AddressType>Expand description
Parse and determine the type of an address (IPv4, IPv6, or hostname)
Returns the AddressType if the address is valid, otherwise returns an error
pub fn parse_address_type(address: &str) -> ClResult<AddressType>Parse and determine the type of an address (IPv4, IPv6, or hostname)
Returns the AddressType if the address is valid, otherwise returns an error