Adapter that manages and stores authentication, authorization and other sensitive data.
Structs
- Access
Token - Access tokens are used to authenticate users
- Action
Token - Action tokens represent federated user actions as signed JWTs (ES384/P-384).
- ApiKey
Info - API key information (without the secret key)
- ApiKey
Validation - Result of validating an API key
- AuthCtx
- Context struct for an authenticated user
- AuthKey
- Represents a profile key
- Auth
Login - Auth
Profile - Represents an auth profile
- Cert
Data - Certificate associated with a tenant
- Create
ApiKey Options - Options for creating an API key
- Create
Proxy Site Data - Data needed to create a new proxy site
- Create
Tenant Data - Data needed to create a new tenant
- Created
ApiKey - Result of creating an API key (includes plaintext key shown only once)
- KeyPair
- A private/public key pair
- List
Tenants Options - Options for listing tenants
- Proxy
Site Config - Configuration for a proxy site (stored as JSON in the config column)
- Proxy
Site Data - Proxy site data from the database
- Tenant
List Item - Tenant list item from auth adapter
- Update
Proxy Site Data - Data to update an existing proxy site
- Webauthn
Constants
Traits
- Auth
Adapter - A
Cloudilloauth adapter