CrdtUpdate

Struct CrdtUpdate 

pub struct CrdtUpdate {
    pub data: Vec<u8>,
    pub client_id: Option<Box<str>>,
}
A binary CRDT update (serialized Yjs sync protocol message).

These updates are the fundamental unit of change in CRDT systems. They can be applied in any order and are commutative.

Fields

data: Vec<u8>

Raw bytes of the update in Yjs sync protocol format

client_id: Option<Box<str>>

Optional user/client ID that created this update

Implementations

Source

impl CrdtUpdate

pub fn new(data: Vec<u8>) -> Self

Create a new CRDT update from raw bytes.

pub fn with_client(data: Vec<u8>, client_id: impl Into<Box<str>>) -> Self

Create a new CRDT update with client ID.