Module validation

Module validation 

Shared low-level format validators.

These live in cloudillo-types so that both the high-level Action DSL (cloudillo-action) and the low-level federation request client (cloudillo-core) can use the exact same definition without creating a dependency cycle between those crates.

Functions

validate_id_tag
Validate idTag format. Returns true if id_tag is a syntactically valid Cloudillo identity tag (see [ID_TAG_RE]).